<?php

namespace Cms\Model\AddressBook\Contact;

use NewcomDigital\Enum\Enum;

/**
 * Class ContactType
 * @package Cms\Model\AddressBook\Contact
 */
class ContactType extends Enum
{

    /**  */
    public const EMAIL = 'email';

    /**  */
    public const PHONE = 'phone';

    /**  */
    public const PHONE_CLOSE = 'phone_close';

    /**  */
    public const FAX = 'fax';

    /**  */
    public const FACEBOOK = 'facebook';

    /**  */
    public const WEBSITE = 'website';
}
